---
title: The Village
id: the-village
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 8
category: people
kind: article
---

## The Village

After hoeing, or perhaps reading and writing, in the forenoon, I
usually bathed again in the pond, swimming across one of its coves for
a stint, and washed the dust of labor from my person, or smoothed out
the last wrinkle which study had made, and for the afternoon was
absolutely free. Every day or two I strolled to the village to hear
some of the gossip which is incessantly going on there, circulating
either from mouth to mouth, or from newspaper to newspaper, and which,
taken in homœopathic doses, was really as refreshing in its way as the
rustle of leaves and the peeping of frogs. As I walked in the woods to
see the birds and squirrels, so I walked in the village to see the men
and boys; instead of the wind among the pines I heard the carts rattle.
In one direction from my house there was a colony of muskrats in the
river meadows; under the grove of elms and buttonwoods in the other
horizon was a village of busy men, as curious to me as if they had been
prairie dogs, each sitting at the mouth of its burrow, or running over
to a neighbor’s to gossip. I went there frequently to observe their
habits. The village appeared to me a great news room; and on one side,
to support it, as once at Redding & Company’s on State Street, they
kept nuts and raisins, or salt and meal and other groceries. Some have
such a vast appetite for the former commodity, that is, the news, and
such sound digestive organs, that they can sit forever in public
avenues without stirring, and let it simmer and whisper through them
like the Etesian winds, or as if inhaling ether, it only producing
numbness and insensibility to pain,—otherwise it would often be painful
to hear,—without affecting the consciousness. I hardly ever failed,
when I rambled through the village, to see a row of such worthies,
either sitting on a ladder sunning themselves, with their bodies
inclined forward and their eyes glancing along the line this way and
that, from time to time, with a voluptuous expression, or else leaning
against a barn with their hands in their pockets, like caryatides, as
if to prop it up. They, being commonly out of doors, heard whatever was
in the wind. These are the coarsest mills, in which all gossip is first
rudely digested or cracked up before it is emptied into finer and more
delicate hoppers within doors. I observed that the vitals of the
village were the grocery, the bar-room, the post-office, and the bank;
and, as a necessary part of the machinery, they kept a bell, a big gun,
and a fire-engine, at convenient places; and the houses were so
arranged as to make the most of mankind, in lanes and fronting one
another, so that every traveller had to run the gantlet, and every man,
woman, and child might get a lick at him. Of course, those who were
stationed nearest to the head of the line, where they could most see
and be seen, and have the first blow at him, paid the highest prices
for their places; and the few straggling inhabitants in the outskirts,
where long gaps in the line began to occur, and the traveller could get
over walls or turn aside into cow paths, and so escape, paid a very
slight ground or window tax. Signs were hung out on all sides to allure
him; some to catch him by the appetite, as the tavern and victualling
cellar; some by the fancy, as the dry goods store and the jeweller’s;
and others by the hair or the feet or the skirts, as the barber, the
shoemaker, or the tailor. Besides, there was a still more terrible
standing invitation to call at every one of these houses, and company
expected about these times. For the most part I escaped wonderfully
from these dangers, either by proceeding at once boldly and without
deliberation to the goal, as is recommended to those who run the
gantlet, or by keeping my thoughts on high things, like Orpheus, who,
“loudly singing the praises of the gods to his lyre, drowned the voices
of the Sirens, and kept out of danger.” Sometimes I bolted suddenly,
and nobody could tell my whereabouts, for I did not stand much about
gracefulness, and never hesitated at a gap in a fence. I was even
accustomed to make an irruption into some houses, where I was well
entertained, and after learning the kernels and very last sieve-ful of
news, what had subsided, the prospects of war and peace, and whether
the world was likely to hold together much longer, I was let out
through the rear avenues, and so escaped to the woods again.

It was very pleasant, when I stayed late in town, to launch myself into
the night, especially if it was dark and tempestuous, and set sail from
some bright village parlor or lecture room, with a bag of rye or Indian
meal upon my shoulder, for my snug harbor in the woods, having made all
tight without and withdrawn under hatches with a merry crew of
thoughts, leaving only my outer man at the helm, or even tying up the
helm when it was plain sailing. I had many a genial thought by the
cabin fire “as I sailed.” I was never cast away nor distressed in any
weather, though I encountered some severe storms. It is darker in the
woods, even in common nights, than most suppose. I frequently had to
look up at the opening between the trees above the path in order to
learn my route, and, where there was no cart-path, to feel with my feet
the faint track which I had worn, or steer by the known relation of
particular trees which I felt with my hands, passing between two pines
for instance, not more than eighteen inches apart, in the midst of the
woods, invariably, in the darkest night. Sometimes, after coming home
thus late in a dark and muggy night, when my feet felt the path which
my eyes could not see, dreaming and absent-minded all the way, until I
was aroused by having to raise my hand to lift the latch, I have not
been able to recall a single step of my walk, and I have thought that
perhaps my body would find its way home if its master should forsake
it, as the hand finds its way to the mouth without assistance. Several
times, when a visitor chanced to stay into evening, and it proved a
dark night, I was obliged to conduct him to the cart-path in the rear
of the house, and then point out to him the direction he was to pursue,
and in keeping which he was to be guided rather by his feet than his
eyes. One very dark night I directed thus on their way two young men
who had been fishing in the pond. They lived about a mile off through
the woods, and were quite used to the route. A day or two after one of
them told me that they wandered about the greater part of the night,
close by their own premises, and did not get home till toward morning,
by which time, as there had been several heavy showers in the mean
while, and the leaves were very wet, they were drenched to their skins.
I have heard of many going astray even in the village streets, when the
darkness was so thick that you could cut it with a knife, as the saying
is. Some who live in the outskirts, having come to town a-shopping in
their wagons, have been obliged to put up for the night; and gentlemen
and ladies making a call have gone half a mile out of their way,
feeling the sidewalk only with their feet, and not knowing when they
turned. It is a surprising and memorable, as well as valuable
experience, to be lost in the woods any time. Often in a snow storm,
even by day, one will come out upon a well-known road and yet find it
impossible to tell which way leads to the village. Though he knows that
he has travelled it a thousand times, he cannot recognize a feature in
it, but it is as strange to him as if it were a road in Siberia. By
night, of course, the perplexity is infinitely greater. In our most
trivial walks, we are constantly, though unconsciously, steering like
pilots by certain well-known beacons and headlands, and if we go beyond
our usual course we still carry in our minds the bearing of some
neighboring cape; and not till we are completely lost, or turned
round,—for a man needs only to be turned round once with his eyes shut
in this world to be lost,—do we appreciate the vastness and strangeness
of Nature. Every man has to learn the points of compass again as often
as he awakes, whether from sleep or any abstraction. Not till we are
lost, in other words not till we have lost the world, do we begin to
find ourselves, and realize where we are and the infinite extent of our
relations.

One afternoon, near the end of the first summer, when I went to the
village to get a shoe from the cobbler’s, I was seized and put into
jail, because, as I have elsewhere related, I did not pay a tax to, or
recognize the authority of, the state which buys and sells men, women,
and children, like cattle at the door of its senate-house. I had gone
down to the woods for other purposes. But, wherever a man goes, men
will pursue and paw him with their dirty institutions, and, if they
can, constrain him to belong to their desperate odd-fellow society. It
is true, I might have resisted forcibly with more or less effect, might
have run “amok” against society; but I preferred that society should
run “amok” against me, it being the desperate party. However, I was
released the next day, obtained my mended shoe, and returned to the
woods in season to get my dinner of huckleberries on Fair-Haven Hill. I
was never molested by any person but those who represented the state. I
had no lock nor bolt but for the desk which held my papers, not even a
nail to put over my latch or windows. I never fastened my door night or
day, though I was to be absent several days; not even when the next
fall I spent a fortnight in the woods of Maine. And yet my house was
more respected than if it had been surrounded by a file of soldiers.
The tired rambler could rest and warm himself by my fire, the literary
amuse himself with the few books on my table, or the curious, by
opening my closet door, see what was left of my dinner, and what
prospect I had of a supper. Yet, though many people of every class came
this way to the pond, I suffered no serious inconvenience from these
sources, and I never missed anything but one small book, a volume of
Homer, which perhaps was improperly gilded, and this I trust a soldier
of our camp has found by this time. I am convinced, that if all men
were to live as simply as I then did, thieving and robbery would be
unknown. These take place only in communities where some have got more
than is sufficient while others have not enough. The Pope’s Homers
would soon get properly distributed.—

                     “Nec bella fuerunt,
     Faginus astabat dum scyphus ante dapes.”

                     “Nor wars did men molest,
     When only beechen bowls were in request.”

“You who govern public affairs, what need have you to employ
punishments? Love virtue, and the people will be virtuous. The virtues
of a superior man are like the wind; the virtues of a common man are
like the grass; the grass, when the wind passes over it, bends.”


